@@ -59,6 +59,9 @@ are additonal arguments used for exec-operations,
 Multiple request object are returned e.g. if a relative check has to be
 performed in order to get the base value as well.
 
+The returned array can contain coderefs which should be executed directly and
+its return value should be used in order to perfoorm the check. 
+
 =cut
 
 sub get_requests {
@@ -66,7 +69,11 @@ sub get_requests {
     my $jmx = shift;
     my $args = shift;
 
+    # If a script is given, extract a subref and return it
+    return [ $self->_extract_script_as_subref($jmx) ] if $self->script;
+
     my $do_read = $self->attribute || $self->value;
+    my $do_exec = $self->operation;
     if ($self->alias) {
         my $alias = JMX::Jmx4Perl::Alias->by_name($self->alias);
         die "No alias '",$self->alias," known" unless $alias;
@@ -76,8 +83,10 @@ sub get_requests {
     my $request;
     if ($do_read) {
         $request = JMX::Jmx4Perl::Request->new(READ,$self->_prepare_read_args($jmx));
-    } else {
+    } elsif ($do_exec) {
         $request = JMX::Jmx4Perl::Request->new(EXEC,$self->_prepare_exec_args($jmx,@$args));
+    } else {
+        die "Neither an attribute/value, an operation or a script given";
     }
     my $method = $self->{np}->opts->{method} || $self->{config}->{method};
     if ($method) {
@@ -107,6 +116,25 @@ sub get_requests {
     return \@requests;
 }
 
+# Create a subref where all params from the outside are available as closures.
+sub _extract_script_as_subref {
+    my $self = shift;
+    my $jmx = shift;
+    my $script = $self->script || die "No script given";
+    my $full_script = <<"EOT";
+sub {
+  my \$j4p = shift;
+  return sub { 
+     $script
+  }
+}
+EOT
+    #print $full_script,"\n";
+    my $sub = eval $full_script;
+    die "Cannot eval script for check ",$self->name,": $@" if $@;
+    return &$sub($jmx);
+}
+
 =item $single_check->exract_responses($responses,$requests,$target)
 
 Extract L<JMX::Jmx4Perl::Response> objects and add the deducted results to 
@@ -135,12 +163,20 @@ sub extract_responses {
     my $request = shift @{$requests};
     #print Dumper($resp);
     my @extra_requests = ();
-    $self->_verify_response($request,$resp);
-    my $value = $self->_extract_value($request,$resp);
+    my $value;
+    my $script_mode = undef;
+    if (ref($request) eq "CODE") {
+        # It's a script, so the 'response' is already the value
+        $script_mode = 1;
+        $value = $resp;
+    } else {
+        $self->_verify_response($request,$resp);
+        $value = $self->_extract_value($request,$resp);
+    }
    
     # Delta handling
     my $delta = $self->delta;
-    if (defined($delta)) {
+    if (defined($delta) && !$script_mode) {
         $value = $self->_delta_value($request,$resp,$delta);
         unless (defined($value)) {
             push @extra_requests,$self->_switch_on_history($request,$opts->{target});
@@ -151,7 +187,7 @@ sub extract_responses {
     # Normalize value 
     my ($value_conv,$unit) = $self->_normalize_value($value);
     my $label = $self->_get_name(cleanup => 1);
-    if ($self->base) {
+    if ($self->base && !$script_mode) {
         # Calc relative value 
         my $base_value = $self->_base_value($self->base,$responses,$requests);
         my $rel_value = sprintf "%2.2f",$base_value ? (int((($value / $base_value) * 10000) + 0.5) / 100) : 0;
@@ -262,7 +298,7 @@ sub _delta_value {
         }
         if (!@$hist_val) {
             # Can happen in some scenarios when requesting the first history entry,
-            # we are return 0 here
+            # we return 0 here
             return 0;
         }
         my $old_value = $hist_val->[0]->{value};
@@ -297,7 +333,7 @@ sub _base_value {
     my $requests = shift;
 
     if (looks_like_number($name)) {
-        # It looks like a number, so we suppose its  the base value itself
+        # It looks like a number, so we suppose its the base value itself
         return $name;
     }
     my $resp = shift @{$responses};
@@ -472,7 +508,7 @@ sub _split_attr_spec {
     my @ret = ();
     # Text:ParseWords is used for split on "/" taking into account
     # quoting and escaping
-    for my $p (&parse_line("/",1,$name)) {
+    for my $p (parse_line("/",1,$name)) {
         # We need to 'unescape' things ourselves
         # since we want quotes to remain in the names (using '0'
         # above would kill those quotes, too). 
@@ -496,8 +532,8 @@ sub _check_threshhold {
         # Verify numeric thresholds
         my @ths = 
           (
-           $self->critical ? (critical => $self->critical) : (),
-           $self->warning ? (warning => $self->warning) : ()
+           defined($self->critical) ? (critical => $self->critical) : (),
+           defined($self->warning) ? (warning => $self->warning) : ()
           );            
         return ($np->check_threshold(check => $value,@ths),"numeric");    
     } else {
@@ -665,13 +701,16 @@ my $CHECK_CONFIG_KEYS = {
                          "numeric" => "numeric",
                          "string" => "string",
                          "label" => "label",
-                         # New:
+
                          "value" => "value",
                          "null" => "null",
+
+                         "script" => "script"
                         };
 
 
 # Get the proper configuration values
+
 sub AUTOLOAD {
     my $self = shift;
     my $np = $self->{np};
